NLSL: pltx_dummy.c File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Macros | Typedefs | Functions | Variables
pltx_dummy.c File Reference
`#include <stdio.h>`
`#include <stdlib.h>`
`#include <string.h>`
`#include "fortrancall.h"`
Include dependency graph for pltx_dummy.c:

Go to the source code of this file.

## Macros
#define | MAX_WINDOWS 5

## Typedefs
typedef char | word[20]

## Functions
void FORTRAN() | getwndws (int *n, word *title)
void FORTRAN() | fstplt (double *y1, double *y2, double *xmin1, double *xstep1, int *indx1, int *wnum)
void FORTRAN() | wpoll ()
void FORTRAN() | shtwndws ()

## Variables
int | numwndws = 0
int | done = 0
int | displayOK = 0

## Macro Definition Documentation

#define MAX_WINDOWS 5

Definition at line 11 of file pltx_dummy.c.

## Typedef Documentation

typedef char word[20]

Definition at line 13 of file pltx_dummy.c.

## Function Documentation

void FORTRAN() fstplt | ( | double * | y1,
|  | double * | y2,
|  | double * | xmin1,
|  | double * | xstep1,
|  | int * | indx1,
|  | int * | wnum
| ) |  |

Definition at line 29 of file pltx_dummy.c.

void FORTRAN() getwndws | ( | int * | n,
|  | word * | title
| ) |  |

Definition at line 22 of file pltx_dummy.c.

void FORTRAN() shtwndws | ( |  | ) |

Definition at line 46 of file pltx_dummy.c.

void FORTRAN() wpoll | ( |  | ) |

Definition at line 40 of file pltx_dummy.c.

## Variable Documentation

int displayOK = 0

Definition at line 18 of file pltx_dummy.c.

int done = 0

Definition at line 17 of file pltx_dummy.c.

int numwndws = 0

Definition at line 16 of file pltx_dummy.c.